@@ -24,6 +24,9 @@ from midb.constants import MEMORY_DB
 from midb.persistent_objects import PDict
 from midb.persistent_objects import PTuple
 from midb.persistent_objects import PList
+from midb.persistent_objects import PObject
+from midb.persistent_objects import MemoryObject
+from midb.persistent_objects import setup_pobject
 
 DEFAULT_ROOT_CLASS = PDict
 
@@ -43,14 +46,12 @@ def get_root(filename=midb.backend.MEMORY_DB,
     :return: a persistent object class that is the root object of the database
     """
     backend = midb.backend.SQLiteBackend(filename=filename,
-                                         root_class=root_type,
-                                         custom_persistent_object_types=custom_persistent_object_types)
+                                         root_class=root_type)
     return backend.root
 
 
 def get_backend(filename=MEMORY_DB,
-                root_type=DEFAULT_ROOT_CLASS,
-                custom_persistent_object_types=[]):
+                root_type=DEFAULT_ROOT_CLASS):
     """
     Similar to get_root() above but returns the backend instead of the root object. This is for use when
     more hands on control of the process is needed.
@@ -61,8 +62,7 @@ def get_backend(filename=MEMORY_DB,
     :return: an SQLiteBackend
     """
     return midb.backend.SQLiteBackend(filename=filename,
-                                      root_class=root_type,
-                                      custom_persistent_object_types=custom_persistent_object_types)
+                                      root_class=root_type)
 
 
 
