@@ -41,7 +41,7 @@ class SQLiteBackend:
     """
     def __init__(self, filename: str = MEMORY_DB,
                  root_class: Union[ClassID, type] = DEFAULT_ROOT_CLASS_ID,
-                 auto_commit: bool = True, custom_persistent_object_types=[]):
+                 auto_commit: bool = True):
         self.filename = filename
 
         root_class_id: ClassID
@@ -55,10 +55,6 @@ class SQLiteBackend:
         self.connection = sqlite3.connect(self.filename)
         if not valid_db(connection=self.connection):
             self.connection = create_db(filename, root_class_id)
-        from midb import PDict, PTuple, PList
-        for cls in custom_persistent_object_types + [PDict, PTuple, PList]:
-            sp = SerializationPair(cls, cls._string_serializer, cls._string_deserializer)
-            register_new_serialization_pair(sp)
 
     def __repr__(self):
         """
