@@ -3,3 +3,6 @@ from midb.persistent_objects._persistentsequence import PersistentSequence
 from midb.persistent_objects._pdict import PDict
 from midb.persistent_objects._ptuple import PTuple
 from midb.persistent_objects._plist import PList
+from midb.persistent_objects._pobject import PObject
+from midb.persistent_objects._pobject import MemoryObject
+from midb.persistent_objects._pobject import setup_pobject
