@@ -25,9 +25,10 @@ for all persistent objects in midb. It is where most of the work that is done to
 persistent object saved to disk and not in memory.
 """
 
-from typing import List, Any, Optional, Iterator, Sequence, cast
+from typing import List, Any, Optional, Iterator, Sequence, cast, Type, ClassVar
 from abc import ABC, abstractmethod
 from midb.backend import SQLiteBackend
+from midb.backend._serialization import SerializationPair, register_new_serialization_pair, _SERIALIZATION_FUNCTIONS
 
 # the attributes that BasePersistentObject uses to store all others in the database.
 # (note: mutmut changes strings and so that we do not have to create some convoluted test I'm just
@@ -37,6 +38,16 @@ ID_ATTR = '_id'  # pragma: no mutate
 TEMP_ATTR = '_temp'  # pragma: no mutate
 
 
+def register_persistent_object_class_with_serializer(cls: Type) -> Type:
+    """
+        A class decorator that will simply register the _string_serializer() and _string_deserializer()
+        functions of the class as a SerializationPair simplifying the creation of Custom Persistent
+        Object types.
+    """
+    register_new_serialization_pair(SerializationPair(cls, cls._string_serializer, cls._string_deserializer))
+    return cls
+
+
 class BasePersistentObject(ABC):
     """
         A BasePersistentObject that is fully initialized will have a '_backend' and an '_id'.
@@ -48,11 +59,8 @@ class BasePersistentObject(ABC):
     _backend: Optional[SQLiteBackend]
     _id: Optional[int]
     _temp: Any
+    _in_memory_class: Type
 
-    @property
-    @abstractmethod
-    def _equivalent_builtin_class(self) -> Any:
-        """ return the built-in class that the sub-class is emulating """
 
     def __init__(self, _backend:Optional[SQLiteBackend] = None, _id: Optional[int] = None, _init_temp: Any = None) -> None:
         """
@@ -168,7 +176,13 @@ class BasePersistentObject(ABC):
         """
             Called when setting an attribute (self.key = value)
         """
-        if key in self._reserved_attributes():
+        is_property_descriptor = False # pragma: no mutate
+        try:
+            if type(self.__class__.__dict__[key]) is property:
+                is_property_descriptor = True
+        except:
+            pass
+        if key in self._reserved_attributes() or is_property_descriptor:
             if (key == TEMP_ATTR and value is not None) and not self.still_temp():
                 # do not set _temp if object is fully initialized
                 return
@@ -209,15 +223,14 @@ class BasePersistentObject(ABC):
 
     def _set(self, key: Any, value: Any) -> None:
         """ Does the heavy lifting of setting a value in the database using the key and the '_id' of the object """
-        if type(value) is dict:
-            from midb.persistent_objects import PDict
-            value = PDict(value)
-        elif type(value) is tuple:
-            from midb.persistent_objects import PTuple
-            value = PTuple(value)
-        elif type(value) is list:
-            from midb.persistent_objects import PList
-            value = PList(value)
+        convertable_types = {cls_serialization_pair.cls: cls_serialization_pair.cls._in_memory_class
+                             for cls_serialization_pair in _SERIALIZATION_FUNCTIONS.values()
+                             if cls_serialization_pair.cls is not None
+                                and issubclass(cls_serialization_pair.cls, BasePersistentObject)}
+
+        for persistent_cls, in_memory_cls in convertable_types.items():
+            if type(value) is in_memory_cls:
+                value = persistent_cls(_init_temp=value)
 
         if self.still_temp():
             self._set_temp(key, value)
@@ -233,7 +246,7 @@ class BasePersistentObject(ABC):
             if isinstance(value, BasePersistentObject):
                 if not hasattr(value, BACKEND_ATTR) or value._backend is None:
                     value._backend = self._backend
-                elif not value.still_temp():
+                elif not value.still_temp() and value._backend != self._backend:
                     value_id = cast(int, value._id)
                     value2 = value.__class__(_backend=self._backend)
                     for k, v in value._backend.get_items(value_id):
