@@ -19,29 +19,27 @@
 # LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
-from typing import Any, Optional, Mapping, Iterable, Dict, Tuple, cast
+from typing import Any, Optional, Mapping, Iterable, Dict, Tuple, cast, Type
 import midb
 from midb.backend import SQLiteBackend
-from midb.persistent_objects import BasePersistentObject
-from midb.persistent_objects._basepersistentobject import TEMP_ATTR
+from midb.persistent_objects._basepersistentobject import BasePersistentObject, TEMP_ATTR, register_persistent_object_class_with_serializer
 
 
+@register_persistent_object_class_with_serializer
 class PDict(BasePersistentObject):
     """ A persistent version of the built-in dict type. """
     _backend: Optional[SQLiteBackend]
     _id: Optional[int]
     _temp: Optional[Dict]
-
-    @property
-    def _equivalent_builtin_class(self):
-        return dict
+    _in_memory_class: Type = dict
 
     def __init__(self, initial_values: Mapping = {}, /,
-                 _backend: Optional[SQLiteBackend] = None, _id: Optional[int] = None,
+                 _backend: Optional[SQLiteBackend] = None, _id: Optional[int] = None, _init_temp: Optional[Dict] = None,
                  **kwargs: Dict) -> None:
-        _init_temp: Dict[Any, Any] = {}
-        _init_temp.update(initial_values)
-        _init_temp.update(kwargs)
+        if _init_temp is None:
+            _init_temp = {}
+            _init_temp.update(initial_values)
+            _init_temp.update(kwargs)
         BasePersistentObject.__init__(self, _backend=_backend, _id=_id, _init_temp=_init_temp)
 
     @classmethod
